@@ -1,10 +1,10 @@
 package Net::DNS::Domain;
 
 #
-# $Id: Domain.pm 1370 2015-07-01 13:48:40Z willem $
+# $Id: Domain.pm 1372 2015-07-02 08:10:58Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1370 $)[1];
+$VERSION = (qw$LastChangedRevision: 1372 $)[1];
 
 
 =head1 NAME
@@ -182,14 +182,14 @@ Net::LibIDN module is installed.
 =cut
 
 sub xname {
-	return &name unless LIBIDN;
-
 	my $name = &name;
-	return $name unless $name =~ /xn--/;
 
-	my $self = shift;
-	return $self->{xname} if defined $self->{xname};
-	$self->{xname} = $utf8->decode( Net::LibIDN::idn_to_unicode $name, 'utf-8' );
+	if ( LIBIDN && $name =~ /xn--/ ) {
+		my $self = shift;
+		return $self->{xname} if defined $self->{xname};
+		return $self->{xname} = $utf8->decode( Net::LibIDN::idn_to_unicode $name, 'utf-8' );
+	}
+	return $name;
 }
 
 
