@@ -1,10 +1,10 @@
 package Net::DNS::Resolver;
 
 #
-# $Id: Resolver.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: Resolver.pm 1404 2015-09-22 13:38:04Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1404 $)[1];
 
 =head1 NAME
 
@@ -15,15 +15,12 @@ Net::DNS::Resolver - DNS resolver class
 
 use strict;
 
-use vars qw(@ISA);
+use constant OS_CONF => "Net::DNS::Resolver::$^O";
+use constant DEFAULT => "Net::DNS::Resolver::UNIX";
 
-BEGIN {
-	for ( $^O, 'UNIX' ) {
-		my $class = join '::', __PACKAGE__, $_;
-		return @ISA = ($class) if eval "require $class;";
-	}
-	die 'failed to load platform specific resolver component';
-}
+use constant CONFIG => scalar eval join ' ', 'require', OS_CONF;
+
+use base ( CONFIG ? OS_CONF : DEFAULT );
 
 
 1;
